==> rso-mod_3.3.11.zip: rso-mod_3.3.11/settings.lua <==
data:extend({
   {
      type = "bool-setting",
      name = "rso-vanilla-biter-generation",
      setting_type = "startup",
      default_value = false,
   },
   {
      type = "bool-setting",
      name = "rso-biter-generation",
      setting_type = "runtime-global",
      default_value = true,
      order = "ca",
   },
   {
      type = "bool-setting",
      name = "rso-use-donuts",
      setting_type = "runtime-global",
      default_value = false,
      order = "ea",
   },   
   {
      type = "bool-setting",
      name = "rso-remove-trees",
      setting_type = "runtime-global",
      default_value = false,
      order = "eb",
   },
   {
      type = "int-setting",
      name = "rso-region-size",
      setting_type = "runtime-global",
      default_value = 7,
      minimum_value = 3,
      maximum_value = 100,
      order = "a",
   },
   {
      type = "double-setting",
      name = "rso-resource-chance",
      setting_type = "runtime-global",
      default_value = 0.5,
      minimum_value = 0.01,
      maximum_value = 1.0,
      order = "ba",
   },
   {
      type = "double-setting",
      name = "rso-enemy-chance",
      setting_type = "runtime-global",
      default_value = 0.25,
      minimum_value = 0.01,
      maximum_value = 1.0,
      order = "cb",
   },
   {
      type = "double-setting",
      name = "rso-enemy-base-size",
      setting_type = "runtime-global",
      default_value = 1.0,
      minimum_value = 1.0,
      maximum_value = 20.0,
      order = "cc",
   },   
   {
      type = "double-setting",
      name = "rso-starting-richness-mult",
      setting_type = "runtime-global",
      default_value = 1.0,
      minimum_value = 0.001,
      maximum_value = 100,
      order = "aa",
   },
   {
      type = "double-setting",
      name = "rso-global-richness-mult",
      setting_type = "runtime-global",
      default_value = 1.0,
      minimum_value = 0.001,
      maximum_value = 100,
      order = "bb",
   },
   {
      type = "double-setting",
      name = "rso-global-size-mult",
      setting_type = "runtime-global",
      default_value = 1.0,
      minimum_value = 0.01,
      maximum_value = 3,
      order = "bc",
   },
   {
      type = "bool-setting",
      name = "rso-infinite-ores-in-start-area",
      setting_type = "runtime-global",
      default_value = false,
      order = "fa",
   },   
   {
      type = "double-setting",
      name = "rso-infinite-ore-threshold",
      setting_type = "runtime-global",
      default_value = 0.7,
      minimum_value = 0.0,
      maximum_value = 1.0,
      order = "fb",
   },
   {
      type = "bool-setting",
      name = "rso-reveal-spawned-resources",
      setting_type = "runtime-global",
      default_value = false,
      order = "ga",
   },
   {
      type = "double-setting",
      name = "rso-distance-exponent",
      setting_type = "runtime-global",
      default_value = 1.1,
      minimum_value = 0.1,
      maximum_value = 3.0,
      order = "da",
   },
   {
      type = "double-setting",
      name = "rso-fluid-distance-exponent",
      setting_type = "runtime-global",
      default_value = 0.6,
      minimum_value = 0.1,
      maximum_value = 3.0,
      order = "db",
   },
   {
      type = "double-setting",
      name = "rso-size-exponent",
      setting_type = "runtime-global",
      default_value = 0.2,
      minimum_value = 0.0,
      maximum_value = 0.5,
      order = "dc",
   },
})

==> rso-mod_3.8.1.zip: rso-mod_3.8.1/settings.lua <==
data:extend({
   {
      type = "bool-setting",
      name = "rso-vanilla-biter-generation",
      setting_type = "startup",
      default_value = false,
   },
   {
      type = "bool-setting",
      name = "rso-biter-generation",
      setting_type = "runtime-global",
      default_value = true,
      order = "ca",
   },
   {
      type = "bool-setting",
      name = "rso-use-donuts",
      setting_type = "runtime-global",
      default_value = false,
      order = "ea",
   },   
   {
      type = "bool-setting",
      name = "rso-remove-trees",
      setting_type = "runtime-global",
      default_value = false,
      order = "eb",
   },
   {
      type = "int-setting",
      name = "rso-region-size",
      setting_type = "runtime-global",
      default_value = 7,
      minimum_value = 3,
      maximum_value = 100,
      order = "a",
   },
   {
      type = "double-setting",
      name = "rso-resource-chance",
      setting_type = "runtime-global",
      default_value = 0.5,
      minimum_value = 0.01,
      maximum_value = 1.0,
      order = "ba",
   },
   {
      type = "double-setting",
      name = "rso-enemy-chance",
      setting_type = "runtime-global",
      default_value = 0.25,
      minimum_value = 0.01,
      maximum_value = 1.0,
      order = "cb",
   },
   {
      type = "double-setting",
      name = "rso-enemy-base-size",
      setting_type = "runtime-global",
      default_value = 1.0,
      minimum_value = 1.0,
      maximum_value = 20.0,
      order = "cc",
   },   
   {
      type = "double-setting",
      name = "rso-starting-richness-mult",
      setting_type = "runtime-global",
      default_value = 1.0,
      minimum_value = 0.001,
      maximum_value = 100,
      order = "aa",
   },
   {
      type = "double-setting",
      name = "rso-global-richness-mult",
      setting_type = "runtime-global",
      default_value = 1.0,
      minimum_value = 0.001,
      maximum_value = 100,
      order = "bb",
   },
   {
      type = "double-setting",
      name = "rso-global-size-mult",
      setting_type = "runtime-global",
      default_value = 1.0,
      minimum_value = 0.01,
      maximum_value = 3,
      order = "bc",
   },
   {
      type = "bool-setting",
      name = "rso-infinite-ores-in-start-area",
      setting_type = "runtime-global",
      default_value = false,
      order = "fa",
   },   
   {
      type = "double-setting",
      name = "rso-infinite-ore-threshold",
      setting_type = "runtime-global",
      default_value = 0.7,
      minimum_value = 0.0,
      maximum_value = 1.0,
      order = "fb",
   },
   {
      type = "bool-setting",
      name = "rso-reveal-spawned-resources",
      setting_type = "runtime-global",
      default_value = false,
      order = "ga",
   },
   {
      type = "bool-setting",
      name = "rso-multi-resource-active",
      setting_type = "runtime-global",
      default_value = true,
      order = "gb",
   },   
   {
      type = "double-setting",
      name = "rso-distance-exponent",
      setting_type = "runtime-global",
      default_value = 1.1,
      minimum_value = 0.0,
      maximum_value = 3.0,
      order = "da",
   },
   {
      type = "double-setting",
      name = "rso-fluid-distance-exponent",
      setting_type = "runtime-global",
      default_value = 0.6,
      minimum_value = 0.0,
      maximum_value = 3.0,
      order = "db",
   },
   {
      type = "double-setting",
      name = "rso-size-exponent",
      setting_type = "runtime-global",
      default_value = 0.2,
      minimum_value = 0.0,
      maximum_value = 0.5,
      order = "dc",
   },
   {
      type = "bool-setting",
      name = "rso-oil-in-start-area",
      setting_type = "runtime-global",
      default_value = true,
      order = "ef",
   },
   {
      type = "bool-setting",
      name = "rso-ore-in-start-area",
      setting_type = "runtime-global",
      default_value = true,
      order = "eg",
   },   
})
